/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 *  WebSphere sMash
 *
 * (C) Copyright IBM Corp. 2007,2008  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */

 
import zero.appbuilder.JavaScriptUtils;

/*
 * Default settings are below.  To enable a setting, pass
 * its name as a query param.  To disable it, prepend "no"
 * to the name.  For example:
 * 
 * ?debug
 * ?nodebug
 * 
 */

def settings = [
	debug: false,
	compress: true,
	console: false,
	ping: true
];

initFromQueryParams(settings);
renderPage(settings);

def renderPage(settings) {
	request.view.abSettings = settings;
	request.view = "index.gt";
	render();
}

def initFromQueryParams(settings) {

	// Default parameter handling.
	settings.each { key, value ->
		def onkey = "${key}";
		def offkey = "no${key}";
		if (zget("/request/params/${onkey}",null) != null) {
			settings[key] = true;
		}
		else if (zget("/request/params/${offkey}",null) != null) {
			settings[key] = false;
		}
	}
	
	// Special handling for debug parameter.
	def debugParam = zget("/request/params/debug",null);
	if (debugParam instanceof String && !debugParam.equals("debug")) {
		// When debug is specified using debug=... the value is taken to be
		// the list of files that should get script tags.  Tags will not
		// be generated for anything outside the list.
		def tokens = debugParam.tokenize(";");
		if (tokens instanceof List && tokens.size() > 0) {
			settings.put("debugScripts",tokens);
		}
	}
	
	// Turn off compression if the compressed JavaScript file is not found.
	if (settings["compress"]) {
		if (!JavaScriptUtils.compressedFileExists()) {
			settings["compress"] = false;
		}
	}
	
	return settings;
}
